@@ -1,5 +1,5 @@
 
-ASCII.SEISN<-function(GH, sel=1,  HEAD=TRUE  )
+ASCII.SEISN<-function(GH, sel=1,  HEAD=TRUE, destdir='.'  )
 {
   if(missing(sel)) { sel = 1:length(GH$STNS) }
   if(missing(HEAD)) { HEAD=TRUE }
@@ -12,6 +12,7 @@ ASCII.SEISN<-function(GH, sel=1,  HEAD=TRUE  )
     {
       j = sel[i]
       fn = paste(sep=".", Aname[1], GH$STNS[j], GH$COMPS[j])
+      fn = paste(destdir, fn, sep='/')
 
       sec = GH$info$sec[i]
       hed = paste(GH$info$yr[i], GH$info$jd[i], GH$info$hr[i], GH$info$mi[i],  sec, GH$info$dt[i])
