@@ -13,7 +13,6 @@ function(P, GU)
         M = which(ustas[i] == P$STAS$name)
         w = which.min(P$STAS$sec[M])
         verts[i] = M[w]
-
       }
 
     #####  old way  verts = P$STAS$comp == "V"
@@ -24,8 +23,6 @@ function(P, GU)
       }
     else
       {
-        
-        
         Vsta = P$STAS$name[verts]
         Vcomp = P$STAS$comp[verts]
         
@@ -37,17 +34,15 @@ function(P, GU)
         
         msta = match(paste(sep=".", osta, ocomp), paste(sep=".", GU$STNS,GU$COMPS) )
         
-        sel = msta
+        sel = msta[!is.na(msta)]
       }
 
     jd =getjul(P$LOC$yr, P$LOC$mo,P$LOC$dom )
-    tadd =  secdif(GU$info$jd[msta], GU$info$hr[msta], GU$info$mi[msta], GU$info$sec[msta], jd, P$LOC$hr, P$LOC$mi, P$LOC$sec)
+    tadd =  secdif(GU$info$jd[sel], GU$info$hr[sel], GU$info$mi[sel],
+        GU$info$sec[sel], jd, P$LOC$hr, P$LOC$mi, P$LOC$sec)
       
 #### cat(sep="\n", paste(sep=' ',P$STAS$name, P$STAS$parr, tadd))
       win = c(max(min(tadd)-1, 0) , max(tadd)+1)
-      
-
-
     return(list(sel=sel, win=win) )
 
   }
